@@ -605,6 +605,14 @@ pub async fn command_upload_nfts(
     let mut paths_iter = glob(glob_str)?.filter_map(Result::ok);
 
     if let Some(p) = paths_iter.next() {
+        if p.is_dir() {
+            println!(
+                "Provided <GLOB>, \"{}\", is a directory. It must match your asset files, `*.<EXT>`, e.g. Remember to enclose it in quotes.",
+                glob_str
+            );
+            return Ok(());
+        }
+
         let parent_dir = p.parent().unwrap();
         let log_dir = arweave.create_log_dir(parent_dir).await?;
         let log_dir_assets = log_dir.join("assets/");
@@ -865,7 +873,9 @@ pub async fn command_write_metaplex_items(
 
     let metaplex_items_path = arweave
         .write_metaplex_items(
-            glob(glob_str)?.filter_map(Result::ok),
+            glob(glob_str)?
+                .filter_map(Result::ok)
+                .map(|p| p.with_extension("json")),
             manifest_path,
             link_file,
         )
